@@ -1,6 +1,6 @@
 /* GNOME-DB Components
  *
- * Copyright (C) 2000 - 2005 The GNOME Foundation.
+ * Copyright (C) 2000 - 2006 The GNOME Foundation.
  *
  * AUTHORS:
  *      Rodrigo Moya <rodrigo@gnome-db.org>
@@ -28,14 +28,8 @@
 #include <gtk/gtkstock.h>
 #include <gtk/gtktable.h>
 #include <gtk/gtkvbbox.h>
-#include <libgnomedb/gnome-db-dsn-config-druid.h>
-#include <libgnomedb/gnome-db-dsn-config.h>
-#include <libgnomedb/gnome-db-grid.h>
-#include <libgnomedb/gnome-db-login-dialog.h>
-#include <libgnomedb/gnome-db-login.h>
-#include <libgnomedb/gnome-db-stock.h>
+#include <libgnomedb/libgnomedb.h>
 #include <libgnomedb/gnome-db-util.h>
-#include <libgnomedb/gnome-db-data-widget.h>
 #include <libgnomeui/gnome-window-icon.h>
 #include "dsn-config.h"
 #include "dsn-properties-dialog.h"
@@ -43,9 +37,10 @@
 #define DSN_CONFIG_DATA "DSN_ConfigData"
 
 typedef struct {
+	GtkWidget *title;
 	GtkWidget *dsn_list;
 	GtkWidget *dialog;
-	guint config_listener;
+	guint      config_listener;
 } DsnConfigPrivate;
 
 static void
@@ -67,6 +62,7 @@ show_data_sources (DsnConfigPrivate *priv)
 	GList *dsn_list;
 	GList *l;
 	GdaDataModel *model;
+	GtkTreeViewColumn *col;
 
 	/* create the data model */
 	model = gda_data_model_array_new (3);
@@ -83,17 +79,20 @@ show_data_sources (DsnConfigPrivate *priv)
 		value_list = g_list_append (value_list, gda_value_new_string (dsn_info->description));
 		value_list = g_list_append (value_list, gda_value_new_boolean (dsn_info->is_global));
 
-		gda_data_model_append_values (model, (const GList *) value_list);
+		gda_data_model_append_values (model, (const GList *) value_list, NULL);
 
 		g_list_foreach (value_list, (GFunc) gda_value_free, NULL);
 		g_list_free (value_list);
 	}
-
+	g_object_set (G_OBJECT (model), "read_only", TRUE, NULL);
 	gda_config_free_data_source_list (dsn_list);
 
 	/* display the new data model */
-	gnome_db_data_widget_set_gda_model (GNOME_DB_DATA_WIDGET (priv->dsn_list), NULL, model);
+	gnome_db_data_widget_set_gda_model (GNOME_DB_DATA_WIDGET (priv->dsn_list), model);
 	g_object_unref (G_OBJECT (model));
+
+	col = gtk_tree_view_get_column (GTK_TREE_VIEW (priv->dsn_list), 1);
+	g_object_set (G_OBJECT (col), "expand", TRUE, NULL);
 }
 
 /*
@@ -125,7 +124,7 @@ list_popup_delete_cb (GtkWidget *menu, gpointer user_data)
 }
 
 static void
-list_popup_cb (GnomeDbGrid *grid, GtkMenu *menu, gpointer user_data)
+list_popup_cb (GnomeDbRawGrid *grid, GtkMenu *menu, gpointer user_data)
 {
 	GtkWidget *item_delete, *item_properties;
 	gboolean ok;
@@ -140,7 +139,7 @@ list_popup_cb (GnomeDbGrid *grid, GtkMenu *menu, gpointer user_data)
 						  G_CALLBACK (list_popup_properties_cb),
 						  user_data);
 
-	list = gnome_db_grid_get_selection (grid);
+	list = gnome_db_raw_grid_get_selection (grid);
 	ok = list != NULL;
 	if (list)
 		g_list_free (list);
@@ -180,28 +179,33 @@ dsn_config_new (void)
 							 priv);
 
 	/* create the main table */
-	table = gnome_db_new_table_widget (2, 1, FALSE);
+	table = gnome_db_new_table_widget (3, 1, FALSE);
 	gtk_box_pack_start (GTK_BOX (dsn), table, TRUE, TRUE, 0);
 
-	/* create the data source list */
-	priv->dsn_list = gnome_db_grid_new ();
- 	gnome_db_data_widget_column_set_editable (GNOME_DB_DATA_WIDGET (priv->dsn_list), 0, FALSE);
-	g_object_set (G_OBJECT (priv->dsn_list), "info_cell_visible", FALSE, "actions_visible", FALSE, NULL);
-
+	/* title */
 	title = g_strdup_printf ("<b>%s</b>\n%s", _("Data Sources"),
 				 _("Configured data sources in the system"));
-	gnome_db_data_widget_set_title (GNOME_DB_DATA_WIDGET (priv->dsn_list), title);
+	priv->title = gnome_db_gray_bar_new (title);
 	g_free (title);
+	gnome_db_gray_bar_set_icon_from_stock (GNOME_DB_GRAY_BAR (priv->title),
+					       GNOME_DB_STOCK_DATABASE, GTK_ICON_SIZE_BUTTON);
+	gtk_table_attach (GTK_TABLE (table), priv->title, 0, 1, 0, 1,
+			  GTK_FILL | GTK_SHRINK,
+			  GTK_FILL | GTK_SHRINK,
+			  0, 0);
+	gtk_widget_show (priv->title);
+
+	/* create the data source list */
+	priv->dsn_list = gnome_db_raw_grid_new (NULL);
+ 	gnome_db_data_widget_column_set_editable (GNOME_DB_DATA_WIDGET (priv->dsn_list), 0, FALSE);
+	g_object_set (priv->dsn_list, "info_cell_visible", FALSE, NULL);
 	
-	gnome_db_data_widget_set_show_title (GNOME_DB_DATA_WIDGET (priv->dsn_list), TRUE);
-	gnome_db_data_widget_set_title_icon_from_stock (GNOME_DB_DATA_WIDGET (priv->dsn_list), 
-							GNOME_DB_STOCK_DATABASE, GTK_ICON_SIZE_BUTTON);
 	gtk_widget_show (priv->dsn_list);
-	g_signal_connect (G_OBJECT (priv->dsn_list), "double_clicked",
+	g_signal_connect (priv->dsn_list, "double_clicked",
 			  G_CALLBACK (list_double_clicked_cb), dsn);
-	g_signal_connect (G_OBJECT (priv->dsn_list), "create_popup_menu",
+	g_signal_connect (priv->dsn_list, "populate_popup",
 			  G_CALLBACK (list_popup_cb), dsn);
-	gtk_table_attach (GTK_TABLE (table), priv->dsn_list, 0, 1, 0, 1,
+	gtk_table_attach (GTK_TABLE (table), priv->dsn_list, 0, 1, 1, 2,
 			  GTK_FILL | GTK_SHRINK | GTK_EXPAND,
 			  GTK_FILL | GTK_SHRINK | GTK_EXPAND,
 			  0, 0);
@@ -210,7 +214,7 @@ dsn_config_new (void)
 	/* add tip */
 	box = gnome_db_new_hbox_widget (FALSE, 6);
         gtk_container_set_border_width (GTK_CONTAINER (box), 6);
-	gtk_table_attach (GTK_TABLE (table), box, 0, 1, 1, 2,
+	gtk_table_attach (GTK_TABLE (table), box, 0, 1, 2, 3,
 			  GTK_FILL,
 			  GTK_FILL,
                           0, 0);
@@ -246,7 +250,7 @@ dsn_config_edit_properties (GtkWidget *dsn)
 
 	priv = g_object_get_data (G_OBJECT (dsn), DSN_CONFIG_DATA);
 	
-	selection = gnome_db_grid_get_selection (GNOME_DB_GRID (priv->dsn_list));
+	selection = gnome_db_raw_grid_get_selection (GNOME_DB_RAW_GRID (priv->dsn_list));
 	if (!selection)
 		return;
 
@@ -263,15 +267,15 @@ dsn_config_edit_properties (GtkWidget *dsn)
 }
 
 static void
-foreach_remove_cb (GnomeDbGrid *grid, gint row, gpointer user_data)
+foreach_remove_cb (GtkTreeModel *tree_model, GtkTreePath *path, GtkTreeIter *iter, DsnConfigPrivate *priv)
 {
-	DsnConfigPrivate *priv;
 	GdaDataModel *model;
 	GtkWidget *dialog, *label;
 	gchar *str1, *str;
 	gchar *dsn;
+	gint row;
 
-	priv = (DsnConfigPrivate *) user_data;
+	gtk_tree_model_get (tree_model, iter, DATA_STORE_COL_MODEL_ROW, &row, -1);
 	model = gnome_db_data_widget_get_gda_model (GNOME_DB_DATA_WIDGET (priv->dsn_list));
 	if (!GDA_IS_DATA_MODEL (model))
 		return;
@@ -311,12 +315,14 @@ void
 dsn_config_delete (GtkWidget *dsn)
 {
 	DsnConfigPrivate *priv;
+	GtkTreeSelection *sel;
 
 	priv = g_object_get_data (G_OBJECT (dsn), DSN_CONFIG_DATA);
-	gnome_db_grid_foreach_selected (GNOME_DB_GRID (priv->dsn_list),
-					(GnomeDbGridForeachFunc) foreach_remove_cb,
-					priv);
 
+	sel = gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->dsn_list));
+
+	gtk_tree_selection_selected_foreach (sel, 
+					     (GtkTreeSelectionForeachFunc) foreach_remove_cb, priv);
 	show_data_sources (priv);
 }
 
@@ -324,31 +330,40 @@ void
 dsn_config_select_all (GtkWidget *dsn)
 {
 	DsnConfigPrivate *priv;
+	GtkTreeSelection *sel;
 
 	priv = g_object_get_data (G_OBJECT (dsn), DSN_CONFIG_DATA);
-	gnome_db_grid_select_all (GNOME_DB_GRID (priv->dsn_list));	
+
+	sel = gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->dsn_list));
+
+	gtk_tree_selection_select_all (sel);
 }
 
 void
 dsn_config_unselect_all (GtkWidget *dsn)
 {
 	DsnConfigPrivate *priv;
+	GtkTreeSelection *sel;
 
 	priv = g_object_get_data (G_OBJECT (dsn), DSN_CONFIG_DATA);
-	gnome_db_grid_unselect_all (GNOME_DB_GRID (priv->dsn_list));	
+
+	sel = gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->dsn_list));
+
+	gtk_tree_selection_unselect_all (sel);
 }
 
 gboolean
 dsn_config_has_selection (GtkWidget *dsn)
-{
+{	
 	DsnConfigPrivate *priv;
-	GList *list;
-	gboolean retval;
+	GtkTreeSelection *sel;
 
 	priv = g_object_get_data (G_OBJECT (dsn), DSN_CONFIG_DATA);
-	list =  gnome_db_grid_get_selection (GNOME_DB_GRID (priv->dsn_list));
-	retval = list == NULL ? FALSE : TRUE;
-	if (list)
-		g_list_free (list);
-	return retval;
+
+	sel = gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->dsn_list));
+
+	if (gtk_tree_selection_count_selected_rows (sel) >= 1)
+		return TRUE;
+	else
+		return FALSE;
 }
