@@ -1,15 +1,46 @@
-#define BUILD_WITH_GNOME
-#include <glib/gi18n.h>
+/* gnome-db-browser.c
+ *
+ * Copyright (C) 2006 Vivien Malerba
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * USA
+ */
+
+#include <glib/gi18n-lib.h>
 #include <libgnomedb/libgnomedb.h>
 #include <libgnomedb/gnome-db-util.h>
 #include <gtk/gtk.h>
 
+/* options */
+gchar *test_file = NULL;
+
+static GOptionEntry entries[] = {
+        { "dict-file", 'd', 0, G_OPTION_ARG_STRING, &test_file, "Dictionary file to use", "file name"},
+        { NULL }
+};
+
 typedef struct {
 	/* General section */
-	GnomeDbDict   *dict;
+	GdaClient     *client;
+	GdaDict       *dict;
 	gchar         *dsn;
 	GtkWidget     *mainwin;
 
+	gchar         *username;
+	gchar         *password;
+	
 	/* Data types page */
 	gint           dt_mode;
 	GtkTextBuffer *dt_textbuffer;
@@ -38,39 +69,48 @@ static void       load_file (BrowserConfig *config);
 int 
 main (int argc, char **argv)
 {
-	GtkWidget *mainwin, *vbox, *menu, *nb, *label, *page;
-	GnomeDbDict *dictionary;
+	GtkWidget *mainwin, *vbox, *menu, *nb, *label, *page, *sb;
+	GdaDict *dictionary;
 	BrowserConfig *config;
 	GdkPixbuf *icon;
+	GOptionContext *context;
+	GError *error = NULL;
+	GdaConnection *cnc;
+
+	/* command line parsing */
+        context = g_option_context_new ("[Data source name] - Test a data source");
+        g_option_context_add_main_entries (context, entries, GETTEXT_PACKAGE);
+        if (!g_option_context_parse (context, &argc, &argv, &error)) {
+                g_warning ("Can't parse arguments: %s", error->message);
+                exit (1);
+        }
+        g_option_context_free (context);
 	
 	/* Initialize i18n support */
-	gtk_set_locale ();
+	bindtextdomain (GETTEXT_PACKAGE, LIBGNOMEDB_LOCALEDIR);
+        bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+        textdomain (GETTEXT_PACKAGE);
 	
 	/* Initialize the widget set */
-	gtk_init (&argc, &argv);
+	gnome_db_init ("gnome-db-browser", PACKAGE_VERSION, argc, argv);
 
 	/* Browser config */
 	config = g_new0 (BrowserConfig, 1);
-	dictionary = GNOME_DB_DICT (gnome_db_dict_new ());
+	dictionary = GDA_DICT (gda_dict_new ());
 	config->dict = dictionary;
-	g_object_set (G_OBJECT (gnome_db_dict_get_server (dictionary)), "with_functions", TRUE, NULL);
-
+	config->client = gda_client_new ();
+	g_object_set (G_OBJECT (config->dict), "with_functions", TRUE, NULL);
+	
 	/* Application init */
-	if (argc > 1) {
-		/* use the DSN source given as argument */
-		GnomeDbServer *srv;
-		
-		srv = gnome_db_dict_get_server (config->dict);
-		if (! gnome_db_server_set_datasource (srv, argv[1])) {
-			g_print ("Datasource '%s' does not exist.\n", argv[1]);
+	if (argc > 1) 
+		config->dsn = g_strdup (argv[1]);
+	else {
+		if (! test_file) {
+			g_print (_("A data source or a dictionary file must be specified.\n"));
 			exit (1);
 		}
-		config->dsn = g_strdup (argv[1]);
-	}
-	else {
-		g_print ("Usage: %s <Data source name>\n\n", argv[0]);
-		exit (1);
 	}
+
 	load_file (config);
 	
 	/* Create the main window */
@@ -102,6 +142,15 @@ main (int argc, char **argv)
 	nb = gtk_notebook_new ();
 	gtk_box_pack_start (GTK_BOX (vbox), nb, TRUE, TRUE, 0);
 
+	/* status bar */
+	sb = gtk_statusbar_new ();
+	gtk_box_pack_start (GTK_BOX (vbox), sb, FALSE, TRUE, 0);
+	cnc = gda_dict_get_connection (config->dict);
+	gtk_statusbar_push (GTK_STATUSBAR (sb), 0, 
+			    cnc && gda_connection_is_opened (cnc) ? 
+			    _("Connection to the database is opened") : 
+			    _("No connection to database"));
+
 	/* tables and views page */
 	page = build_tables_views_page (config);
 	label = gtk_label_new (_("Tables and Views"));
@@ -117,68 +166,116 @@ main (int argc, char **argv)
 	gtk_widget_show_all (mainwin);
 	
 	gtk_main ();
-	g_object_unref (G_OBJECT (dictionary));
 
 	return 0;
 }
 
-static void open_connection (BrowserConfig *config, gboolean force_update);
+static gboolean get_open_connection_args (BrowserConfig *config);
 static void update_dbms_data_cb (GtkWidget *wid, BrowserConfig *config);
 static void
 load_file (BrowserConfig *config)
 {
 	GError *error = NULL;
-	GnomeDbServer *server = gnome_db_dict_get_server (config->dict);
+	GdaConnection *cnc = gda_dict_get_connection (config->dict);
+	gchar *filename;
+	gboolean request_sync = FALSE;
 
-	gnome_db_server_reset (gnome_db_dict_get_server (config->dict));
-	/* actual file loading */
-	if (!gnome_db_dict_load_xml (config->dict, &error)) {
-		if (error && (error->code == GNOME_DB_DICT_LOAD_FILE_NOT_EXIST_ERROR)) {
-			GtkWidget *msg;
-			gchar *str;
+	/* filename for the dictionary */
+	if (test_file)
+		filename = test_file;
+	else {
+		filename = gda_dict_compute_xml_filename (config->dict, config->dsn, NULL, &error);
+		if (!filename)
+			g_error ("Could not compute output XML file name: %s", error ? error->message:
+				 _("Unknown error"));
+	}
+	gda_dict_set_xml_filename (config->dict, filename);
+	if (!test_file)
+		g_free (filename);
 
-			str = g_strdup_printf ("<b>%s</b>\n\n%s",
-					       _("Do you want to build the database dictionary?"),
-					       _("The database dictionary must be built before the database can be browsed. "
-						 "The process only takes a few minutes.\n"
-						 "\n"
-						 "The dictionary will need to be rebuilt only if the database structure "
-                                                 "changes."));
-			
-			msg = gtk_message_dialog_new_with_markup (GTK_WINDOW (config->mainwin), 
-								  GTK_DIALOG_DESTROY_WITH_PARENT,
-								  GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, 
-								  str);
-			g_free (str);
-			if (gtk_dialog_run (GTK_DIALOG (msg)) == GTK_RESPONSE_YES) 
-				open_connection (config, TRUE);
-			else {
-				g_print ("Can't build the dictionary...\n");
-				exit (1);
-			}
-			gtk_widget_destroy (msg);
-			g_error_free (error);
-			error = NULL;
-		}
+	/* dictionary loading */
+	if (!gda_dict_load (config->dict, &error)) {
+		if (error && (error->code == GDA_DICT_LOAD_FILE_NOT_EXIST_ERROR))
+			request_sync = TRUE;
 		else {
 			g_print ("Error loading dictionary file:\n%s\n",
 				 error ? error->message : _("unreported error"));
 			exit (1);
 		}
+		g_error_free (error);
+	}
+	else {
+		if (!config->dsn)
+			g_object_get (G_OBJECT (config->dict), "dsn", &(config->dsn), NULL);
+	}
+
+	/* open the connection if possible */
+	if (!cnc && config->dsn && *(config->dsn)) {
+		while (!cnc && get_open_connection_args (config)) {
+			cnc = gda_client_open_connection (config->client, config->dsn, 
+							  config->username, config->password, 
+							  0, &error);
+			if (!cnc) {
+				GtkWidget *errdialog;
+
+				errdialog = gnome_db_new_alert (NULL,
+								GTK_MESSAGE_ERROR, 
+								_("Error opening connection:"),
+								error && error->message ? 
+								error->message : _("no detail"));
+				gtk_widget_show (errdialog);
+				gtk_dialog_run (GTK_DIALOG (errdialog));
+				gtk_widget_destroy (errdialog);
+
+				g_error_free (error);
+				error = NULL;
+
+				g_free (config->username);
+				config->username = NULL;
+				g_free (config->password);
+				config->password = NULL;
+			}
+			else {
+				gda_dict_set_connection (config->dict, cnc);
+				g_object_unref (cnc);
+			}
+		}
+	}
+
+	/* ask permission to perform a DBMS sync if requested */
+	if (cnc && request_sync) {
+		GtkWidget *msg;
+		gchar *str;
+		
+		str = g_strdup_printf ("<b>%s</b>\n\n%s",
+				       _("Do you want to build the database dictionary?"),
+				       _("The database dictionary must be built before the database can be browsed. "
+					 "The process only takes a few minutes.\n"
+					 "\n"
+					 "The dictionary will need to be rebuilt only if the database structure "
+					 "changes."));
+		
+		msg = gtk_message_dialog_new_with_markup (GTK_WINDOW (config->mainwin), 
+							  GTK_DIALOG_DESTROY_WITH_PARENT,
+							  GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, 
+							  str);
+		g_free (str);
+		if (gtk_dialog_run (GTK_DIALOG (msg)) == GTK_RESPONSE_YES)
+			update_dbms_data_cb (NULL, config);
+		gtk_widget_destroy (msg);
 	}
-	else 
-		open_connection (config, FALSE);
 }
 
-static void
-open_connection (BrowserConfig *config, gboolean force_update)
+static gboolean
+get_open_connection_args (BrowserConfig *config)
 {
 	GtkWidget *dialog, *login;
 	gchar *title;
-	gboolean conn_opened = FALSE;
-	GError *error = NULL;
-	GnomeDbServer *server = gnome_db_dict_get_server (config->dict);
+	gboolean retval;
 	
+	if (config->username)
+		return TRUE;
+
 	title = g_strdup_printf (_("Login for %s"), config->dsn);
 	dialog = gnome_db_login_dialog_new (title);
 	g_free (title);
@@ -186,36 +283,14 @@ open_connection (BrowserConfig *config, gboolean force_update)
 	gnome_db_login_set_dsn (GNOME_DB_LOGIN (login), config->dsn);
 	gnome_db_login_set_show_dsn_selector (GNOME_DB_LOGIN (login), FALSE);
 	
-	while (!conn_opened && gnome_db_login_dialog_run (GNOME_DB_LOGIN_DIALOG (dialog))) {
-		gnome_db_server_set_user_name (server, 
-					       gnome_db_login_dialog_get_username (GNOME_DB_LOGIN_DIALOG (dialog)));
-		gnome_db_server_set_user_password (server, 
-						   gnome_db_login_dialog_get_password (GNOME_DB_LOGIN_DIALOG (dialog)));
-		
-		conn_opened = gnome_db_server_open_connect (server, &error);
-		if (!conn_opened) {
-			GtkWidget *errdialog;
-			
-			errdialog = gnome_db_new_alert (GTK_WINDOW (dialog), 
-							GTK_MESSAGE_ERROR, _("Error opening connection:"), 
-							error && error->message ? error->message : _("no detail"));
-			gtk_widget_show (errdialog);
-			gtk_dialog_run (GTK_DIALOG (errdialog));
-			gtk_widget_destroy (errdialog);
-
-			if (error)
-				g_error_free (error);
-			error = NULL;
-		}
-		else 
-			if (force_update)
-				update_dbms_data_cb (NULL, config);
+	retval = gnome_db_login_dialog_run (GNOME_DB_LOGIN_DIALOG (dialog));
+	if (retval) {
+		config->username = g_strdup (gnome_db_login_dialog_get_username (GNOME_DB_LOGIN_DIALOG (dialog)));
+		config->password = g_strdup (gnome_db_login_dialog_get_password (GNOME_DB_LOGIN_DIALOG (dialog)));
 	}
 	gtk_widget_destroy (dialog);
-	if (!conn_opened) {
-		g_print ("Can't open connection...\n");
-		exit (1);
-	}
+
+	return retval;
 }
 
 static void sql_console_cb (GtkWidget *wid, BrowserConfig *config);
@@ -228,6 +303,7 @@ build_menu (BrowserConfig *config, GtkWidget *mainwin)
 {
 	GtkWidget *menubar1, *menuitem1, *menuitem1_menu, *entry;
 	GtkAccelGroup *accel_group;
+	GdaConnection *cnc = gda_dict_get_connection (config->dict);
 
 	accel_group = gtk_accel_group_new ();
 
@@ -259,6 +335,7 @@ build_menu (BrowserConfig *config, GtkWidget *mainwin)
 
 	entry = gtk_menu_item_new_with_mnemonic (_("Synchronise metadata with DBMS"));
 	gtk_widget_show (entry);
+	gtk_widget_set_sensitive (entry, cnc && gda_connection_is_opened (cnc));
 	gtk_container_add (GTK_CONTAINER (menuitem1_menu), entry);
 
 	g_signal_connect (G_OBJECT (entry), "activate",
@@ -266,6 +343,7 @@ build_menu (BrowserConfig *config, GtkWidget *mainwin)
 
 	entry = gtk_menu_item_new_with_mnemonic (_("SQL Console"));
 	gtk_widget_show (entry);
+	gtk_widget_set_sensitive (entry, cnc && gda_connection_is_opened (cnc));
 	gtk_container_add (GTK_CONTAINER (menuitem1_menu), entry);
 
 	g_signal_connect (G_OBJECT (entry), "activate",
@@ -282,14 +360,14 @@ static void
 update_dbms_data_cb (GtkWidget *wid, BrowserConfig *config)
 {
 	GtkWidget *dlg, *updview;
-	GnomeDbDatabase *db;
-	GnomeDbServer *srv;
+	GdaDictDatabase *db;
+	GdaConnection *cnc;
 	GError *error = NULL;
 	gboolean stopped = FALSE;
 
-	db = gnome_db_dict_get_database (config->dict);
-	srv = gnome_db_dict_get_server (config->dict);
-	g_assert (gnome_db_server_conn_is_opened (srv));
+	db = gda_dict_get_database (config->dict);
+	cnc = gda_dict_get_connection (config->dict);
+	g_assert (gda_connection_is_opened (cnc));
 
 	dlg = gtk_dialog_new_with_buttons (_("Metadata synchronisation"),
 					   GTK_WINDOW (config->mainwin), 
@@ -302,8 +380,8 @@ update_dbms_data_cb (GtkWidget *wid, BrowserConfig *config)
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG(dlg)->vbox), updview, TRUE, TRUE, 0);
 	gtk_widget_show (dlg);
 	/* data types, functions and aggregates */
-	if (!gnome_db_server_update_dbms_data (srv, &error)) {
-		if (error->code != GNOME_DB_SERVER_META_DATA_UPDATE_USER_STOPPED) {
+	if (!gda_dict_update_dbms_data (config->dict, &error)) {
+		if (error->code != GDA_DICT_META_DATA_UPDATE_USER_STOPPED) {
 			GtkWidget *msg;
 			
 			msg = gtk_message_dialog_new (GTK_WINDOW (config->mainwin), 
@@ -319,8 +397,8 @@ update_dbms_data_cb (GtkWidget *wid, BrowserConfig *config)
 		error = NULL;	
 	}
 	/* database */
-	if (!stopped && !gnome_db_database_update_dbms_data (db, &error)) {
-		if (error->code != GNOME_DB_DATABASE_META_DATA_UPDATE_USER_STOPPED) {
+	if (!stopped && !gda_dict_database_update_dbms_data (db, &error)) {
+		if (error->code != GDA_DICT_DATABASE_META_DATA_UPDATE_USER_STOPPED) {
 			GtkWidget *msg;
 			
 			msg = gtk_message_dialog_new (GTK_WINDOW (config->mainwin), 
@@ -338,7 +416,7 @@ update_dbms_data_cb (GtkWidget *wid, BrowserConfig *config)
 
 	gtk_widget_destroy (dlg);
 	if (!stopped) {
-		if (!gnome_db_dict_save_xml (config->dict, &error)) {
+		if (!gda_dict_save (config->dict, &error)) {
 			GtkWidget *msg;
 			
 			msg = gtk_message_dialog_new (GTK_WINDOW (config->mainwin), 
@@ -357,7 +435,7 @@ update_dbms_data_cb (GtkWidget *wid, BrowserConfig *config)
 static void
 stop_dbms_update_cb (GtkWidget *dlg, gint response, BrowserConfig *config)
 {
-	gnome_db_server_stop_update_dbms_data (gnome_db_dict_get_server (config->dict));
+	gda_dict_stop_update_dbms_data (config->dict);
 }
 
 static void
@@ -501,7 +579,7 @@ dt_mode_changed_cb (GtkWidget *wid, BrowserConfig *config)
 }
 
 static gchar *
-function_get_args (GnomeDbServerFunction *func)
+function_get_args (GdaDictFunction *func)
 {
 	GString *string;
 	const GSList *args;
@@ -509,7 +587,7 @@ function_get_args (GnomeDbServerFunction *func)
 	gboolean firstarg = TRUE;
 
 	string = g_string_new ("");
-	args = gnome_db_server_function_get_arg_types (func);
+	args = gda_dict_function_get_arg_types (func);
 	g_string_append (string, " (");
 	while (args) {
 		if (firstarg)
@@ -518,7 +596,7 @@ function_get_args (GnomeDbServerFunction *func)
 			g_string_append (string, ", ");
 		if (args->data) 
 			g_string_append (string,
-					 gnome_db_server_data_type_get_sqlname (GNOME_DB_SERVER_DATA_TYPE (args->data)));
+					 gda_dict_type_get_sqlname (GDA_DICT_TYPE (args->data)));
 		else
 			g_string_append (string, "*");
 				 
@@ -550,24 +628,24 @@ dt_selection_changed_cb (GnomeDbSelector *mgsel, GObject *dt, BrowserConfig *con
 	else {
 		GSList *list, *funcs, *args, *aggs;
 		gboolean getfunc;
-		GnomeDbServerDataType *ldt;
+		GdaDictType *ldt;
 		
-		funcs = gnome_db_server_get_functions (gnome_db_dict_get_server (config->dict));
-		aggs = gnome_db_server_get_aggregates (gnome_db_dict_get_server (config->dict));
+		funcs = gda_dict_get_functions (config->dict);
+		aggs = gda_dict_get_aggregates (config->dict);
 		list = g_slist_concat (funcs, aggs);
 		funcs = list;
 		while (list) {
 			getfunc = FALSE;
 			switch (config->dt_mode) {
 			case 0:
-				if (IS_GNOME_DB_SERVER_FUNCTION (list->data)) {
-					ldt = gnome_db_server_function_get_ret_type (GNOME_DB_SERVER_FUNCTION (list->data));
+				if (GDA_IS_DICT_FUNCTION (list->data)) {
+					ldt = gda_dict_function_get_ret_type (GDA_DICT_FUNCTION (list->data));
 					getfunc = (G_OBJECT (ldt) == dt) ? TRUE : FALSE;
 				}
 				break;
 			case 1:
-				if (IS_GNOME_DB_SERVER_FUNCTION (list->data)) {
-					args = gnome_db_server_function_get_arg_types (GNOME_DB_SERVER_FUNCTION (list->data));
+				if (GDA_IS_DICT_FUNCTION (list->data)) {
+					args = (GSList *) gda_dict_function_get_arg_types (GDA_DICT_FUNCTION (list->data));
 					while (args && !getfunc) {
 						if (args->data == (gpointer) dt)
 							getfunc = TRUE;
@@ -576,8 +654,8 @@ dt_selection_changed_cb (GnomeDbSelector *mgsel, GObject *dt, BrowserConfig *con
 				}
 				break;
 			case 2:
-				if (IS_GNOME_DB_SERVER_AGGREGATE (list->data)) {
-					ldt = gnome_db_server_aggregate_get_arg_type (GNOME_DB_SERVER_AGGREGATE (list->data));
+				if (GDA_IS_DICT_AGGREGATE (list->data)) {
+					ldt = gda_dict_aggregate_get_arg_type (GDA_DICT_AGGREGATE (list->data));
 					getfunc = !ldt || (G_OBJECT (ldt) == dt) ? TRUE : FALSE;
 				}
 				break;
@@ -586,17 +664,17 @@ dt_selection_changed_cb (GnomeDbSelector *mgsel, GObject *dt, BrowserConfig *con
 			if (getfunc) {
 				gchar *str;
 
-				str = gnome_db_base_get_name (GNOME_DB_BASE (list->data));
+				str = (gchar *) gda_object_get_name (GDA_OBJECT (list->data));
 				gtk_text_buffer_get_end_iter (config->dt_textbuffer, &end);
 				gtk_text_buffer_insert_with_tags_by_name (config->dt_textbuffer, 
 									  &end, str, -1, 
 									  "funcname", NULL);
 
-				if (IS_GNOME_DB_SERVER_FUNCTION (list->data))
-					str = function_get_args (GNOME_DB_SERVER_FUNCTION (list->data));
+				if (GDA_IS_DICT_FUNCTION (list->data))
+					str = function_get_args (GDA_DICT_FUNCTION (list->data));
 				else {
-					if ((ldt = gnome_db_server_aggregate_get_arg_type (GNOME_DB_SERVER_AGGREGATE (list->data)))) {
-						str = g_strdup_printf (" (%s)", gnome_db_base_get_name (GNOME_DB_BASE (ldt)));
+					if ((ldt = gda_dict_aggregate_get_arg_type (GDA_DICT_AGGREGATE (list->data)))) {
+						str = g_strdup_printf (" (%s)", gda_object_get_name (GDA_OBJECT (ldt)));
 					}
 					else
 						str = g_strdup (" (*)");
@@ -605,7 +683,7 @@ dt_selection_changed_cb (GnomeDbSelector *mgsel, GObject *dt, BrowserConfig *con
 				gtk_text_buffer_insert (config->dt_textbuffer, &end, str, -1);
 				g_free (str);
 
-				str = gnome_db_base_get_description (GNOME_DB_BASE (list->data));
+				str = (gchar *) gda_object_get_description (GDA_OBJECT (list->data));
 				if (str && *str) {
 					gchar *str2 = g_strdup_printf (" -- %s\n", str);
 					gtk_text_buffer_get_end_iter (config->dt_textbuffer, &end);
@@ -739,12 +817,12 @@ tables_selection_changed_cb (GnomeDbSelector *mgsel, GObject *obj, BrowserConfig
 		gtk_text_buffer_set_text (config->db_textbuffer, _("Select a table or a table's field..."), -1);
 	else {
 		gtk_text_buffer_get_start_iter (config->db_textbuffer, &current);
-		if (IS_GNOME_DB_TABLE (obj)) {
+		if (GDA_IS_DICT_TABLE (obj)) {
 			gchar *str;
-			GnomeDbTable *table = GNOME_DB_TABLE (obj);
+			GdaDictTable *table = GDA_DICT_TABLE (obj);
 			GSList *constraints, *list;
 
-			if (gnome_db_table_is_view (table))
+			if (gda_dict_table_is_view (table))
 				str = _("View:");
 			else
 				str = _("Table:");
@@ -755,23 +833,23 @@ tables_selection_changed_cb (GnomeDbSelector *mgsel, GObject *obj, BrowserConfig
 			gtk_text_buffer_insert_with_tags_by_name (config->db_textbuffer, 
 								  &current, " ", -1, 
 								  "section", NULL);
-			gtk_text_buffer_insert (config->db_textbuffer, &current, gnome_db_base_get_name (GNOME_DB_BASE (obj)), -1);
+			gtk_text_buffer_insert (config->db_textbuffer, &current, gda_object_get_name (GDA_OBJECT (obj)), -1);
 			gtk_text_buffer_insert (config->db_textbuffer, &current, "\n\n", -1);
 			
 			/* constraints list */
-			constraints = gnome_db_table_get_constraints (table);
+			constraints = gda_dict_table_get_constraints (table);
 
 			/* PKey */
 			list = constraints;
 			while (list) {
 				gboolean first = TRUE;
-				if (gnome_db_constraint_get_constraint_type (GNOME_DB_CONSTRAINT (list->data)) == 
+				if (gda_dict_constraint_get_constraint_type (GDA_DICT_CONSTRAINT (list->data)) == 
 				    CONSTRAINT_PRIMARY_KEY) {
-					GnomeDbConstraint *cstr = GNOME_DB_CONSTRAINT (list->data);
+					GdaDictConstraint *cstr = GDA_DICT_CONSTRAINT (list->data);
 					GSList *fields, *list2;
 					gboolean header = FALSE;
 
-					fields = gnome_db_constraint_pkey_get_fields (cstr);
+					fields = gda_dict_constraint_pkey_get_fields (cstr);
 					list2 = fields;
 					while (list2) {
 						if (!header) {
@@ -789,7 +867,7 @@ tables_selection_changed_cb (GnomeDbSelector *mgsel, GObject *obj, BrowserConfig
 							gtk_text_buffer_insert (config->db_textbuffer, &current, ", ", -1);
 
 						gtk_text_buffer_insert (config->db_textbuffer, &current, 
-									gnome_db_base_get_name (GNOME_DB_BASE (list2->data)), -1);
+									gda_object_get_name (GDA_OBJECT (list2->data)), -1);
 						list2 = g_slist_next (list2);
 					}
 					g_slist_free (fields);
@@ -801,16 +879,16 @@ tables_selection_changed_cb (GnomeDbSelector *mgsel, GObject *obj, BrowserConfig
 			/* FKey */
 			list = constraints;
 			while (list) {
-				if (gnome_db_constraint_get_constraint_type (GNOME_DB_CONSTRAINT (list->data)) == 
+				if (gda_dict_constraint_get_constraint_type (GDA_DICT_CONSTRAINT (list->data)) == 
 				    CONSTRAINT_FOREIGN_KEY) {
-					GnomeDbConstraint *cstr = GNOME_DB_CONSTRAINT (list->data);
+					GdaDictConstraint *cstr = GDA_DICT_CONSTRAINT (list->data);
 					GSList *fields, *list2;
 					gboolean header = FALSE;
 
-					fields = gnome_db_constraint_fkey_get_fields (cstr);
+					fields = gda_dict_constraint_fkey_get_fields (cstr);
 					list2 = fields;
 					while (list2) {
-						GnomeDbEntity *ent;
+						GdaEntity *ent;
 						if (!header) {
 							header = TRUE;
 							gtk_text_buffer_insert_with_tags_by_name (config->db_textbuffer,
@@ -820,14 +898,14 @@ tables_selection_changed_cb (GnomeDbSelector *mgsel, GObject *obj, BrowserConfig
 							gtk_text_buffer_insert (config->db_textbuffer, &current, "\n", -1);
 						}
 						
-						str = gnome_db_base_get_name (GNOME_DB_BASE (GNOME_DB_CONSTRAINT_FK_PAIR (list2->data)->fkey));
+						str = (gchar *) gda_object_get_name (GDA_OBJECT (GDA_DICT_CONSTRAINT_FK_PAIR (list2->data)->fkey));
 						gtk_text_buffer_insert (config->db_textbuffer, &current, str, -1);
 						gtk_text_buffer_insert (config->db_textbuffer, &current, " --> ", -1);
-						ent = gnome_db_field_get_entity (GNOME_DB_FIELD (GNOME_DB_CONSTRAINT_FK_PAIR (list2->data)->ref_pkey));
-						str = gnome_db_base_get_name (GNOME_DB_BASE (ent));
+						ent = gda_entity_field_get_entity (GDA_ENTITY_FIELD (GDA_DICT_CONSTRAINT_FK_PAIR (list2->data)->ref_pkey));
+						str = (gchar *) gda_object_get_name (GDA_OBJECT (ent));
 						gtk_text_buffer_insert (config->db_textbuffer, &current, str, -1);
 						gtk_text_buffer_insert (config->db_textbuffer, &current, ".", -1);
-						str = gnome_db_base_get_name (GNOME_DB_BASE (GNOME_DB_CONSTRAINT_FK_PAIR (list2->data)->ref_pkey));
+						str = (gchar *) gda_object_get_name (GDA_OBJECT (GDA_DICT_CONSTRAINT_FK_PAIR (list2->data)->ref_pkey));
 						gtk_text_buffer_insert (config->db_textbuffer, &current, str, -1);
 						gtk_text_buffer_insert (config->db_textbuffer, &current, "\n", -1);
 						
@@ -842,13 +920,13 @@ tables_selection_changed_cb (GnomeDbSelector *mgsel, GObject *obj, BrowserConfig
 			/* Unique */
 			list = constraints;
 			while (list) {
-				if (gnome_db_constraint_get_constraint_type (GNOME_DB_CONSTRAINT (list->data)) == 
+				if (gda_dict_constraint_get_constraint_type (GDA_DICT_CONSTRAINT (list->data)) == 
 				    CONSTRAINT_UNIQUE) {
-					GnomeDbConstraint *cstr = GNOME_DB_CONSTRAINT (list->data);
+					GdaDictConstraint *cstr = GDA_DICT_CONSTRAINT (list->data);
 					GSList *fields, *list2;
 					gboolean header = FALSE;
 
-					fields = gnome_db_constraint_unique_get_fields (cstr);
+					fields = gda_dict_constraint_unique_get_fields (cstr);
 					list2 = fields;
 					while (list2) {
 						if (!header) {
@@ -863,7 +941,7 @@ tables_selection_changed_cb (GnomeDbSelector *mgsel, GObject *obj, BrowserConfig
 							gtk_text_buffer_insert (config->db_textbuffer, &current, ", ", -1);
 
 						gtk_text_buffer_insert (config->db_textbuffer, &current, 
-									gnome_db_base_get_name (GNOME_DB_BASE (list2->data)), -1);
+									gda_object_get_name (GDA_OBJECT (list2->data)), -1);
 						
 						list2 = g_slist_next (list2);
 					}
@@ -879,10 +957,10 @@ tables_selection_changed_cb (GnomeDbSelector *mgsel, GObject *obj, BrowserConfig
 			
 		}
 
-		if (IS_GNOME_DB_TABLE_FIELD (obj)) {
+		if (GDA_IS_DICT_FIELD (obj)) {
 			gchar *str;
-			GnomeDbServerDataType *type;
-			GnomeDbTableField *field = GNOME_DB_TABLE_FIELD (obj);
+			GdaDictType *type;
+			GdaDictField *field = GDA_DICT_FIELD (obj);
 
 			gtk_text_buffer_insert_with_tags_by_name (config->db_textbuffer, 
 								  &current, _("Field:"), -1, 
@@ -890,24 +968,24 @@ tables_selection_changed_cb (GnomeDbSelector *mgsel, GObject *obj, BrowserConfig
 			gtk_text_buffer_insert_with_tags_by_name (config->db_textbuffer, 
 								  &current, " ", -1, 
 								  "section", NULL);
-			gtk_text_buffer_insert (config->db_textbuffer, &current, gnome_db_base_get_name (GNOME_DB_BASE (obj)), -1);
+			gtk_text_buffer_insert (config->db_textbuffer, &current, gda_object_get_name (GDA_OBJECT (obj)), -1);
 			gtk_text_buffer_insert (config->db_textbuffer, &current, "\n\n", -1);
 
-			type = gnome_db_field_get_data_type (GNOME_DB_FIELD (field));
+			type = gda_entity_field_get_data_type (GDA_ENTITY_FIELD (field));
 			gtk_text_buffer_insert (config->db_textbuffer, &current, _("Data type:"), -1);
 			gtk_text_buffer_insert (config->db_textbuffer, &current, " ", -1);
-			gtk_text_buffer_insert (config->db_textbuffer, &current, gnome_db_base_get_name (GNOME_DB_BASE (type)), -1);
+			gtk_text_buffer_insert (config->db_textbuffer, &current, gda_object_get_name (GDA_OBJECT (type)), -1);
 			gtk_text_buffer_insert (config->db_textbuffer, &current, "\n", -1);
 
 			gtk_text_buffer_insert (config->db_textbuffer, &current, _("Description:"), -1);
 			gtk_text_buffer_insert (config->db_textbuffer, &current, " ", -1);
-			gtk_text_buffer_insert (config->db_textbuffer, &current, gnome_db_base_get_description (GNOME_DB_BASE (obj)), -1);
+			gtk_text_buffer_insert (config->db_textbuffer, &current, gda_object_get_description (GDA_OBJECT (obj)), -1);
 			gtk_text_buffer_insert (config->db_textbuffer, &current, "\n", -1);
 
 			gtk_text_buffer_insert (config->db_textbuffer, &current, _("Length:"), -1);
 			gtk_text_buffer_insert (config->db_textbuffer, &current, " ", -1);
-			if (gnome_db_table_field_get_length (field) != -1) {
-				str = g_strdup_printf ("%d", gnome_db_table_field_get_length (field));
+			if (gda_dict_field_get_length (field) != -1) {
+				str = g_strdup_printf ("%d", gda_dict_field_get_length (field));
 				gtk_text_buffer_insert (config->db_textbuffer, &current, str, -1);
 				g_free (str);
 			}
@@ -915,8 +993,8 @@ tables_selection_changed_cb (GnomeDbSelector *mgsel, GObject *obj, BrowserConfig
 
 			gtk_text_buffer_insert (config->db_textbuffer, &current, _("Scale:"), -1);
 			gtk_text_buffer_insert (config->db_textbuffer, &current, " ", -1);
-			if (gnome_db_table_field_get_scale (field) != -1) {
-				str = g_strdup_printf ("%d", gnome_db_table_field_get_scale (field));
+			if (gda_dict_field_get_scale (field) != -1) {
+				str = g_strdup_printf ("%d", gda_dict_field_get_scale (field));
 				gtk_text_buffer_insert (config->db_textbuffer, &current, str, -1);
 				g_free (str);
 			}
@@ -925,15 +1003,15 @@ tables_selection_changed_cb (GnomeDbSelector *mgsel, GObject *obj, BrowserConfig
 			
 			gtk_text_buffer_insert (config->db_textbuffer, &current, _("NULL allowed:"), -1);
 			gtk_text_buffer_insert (config->db_textbuffer, &current, " ", -1);
-			str = gnome_db_table_field_is_null_allowed (field) ? _("Yes") : _("No");
+			str = gda_dict_field_is_null_allowed (field) ? _("Yes") : _("No");
 			gtk_text_buffer_insert (config->db_textbuffer, &current, str, -1);
 			gtk_text_buffer_insert (config->db_textbuffer, &current, "\n", -1);
 			gtk_text_buffer_insert (config->db_textbuffer, &current, "\n", -1);
 
 			gtk_text_buffer_insert (config->db_textbuffer, &current, _("Primary key:"), -1);
 			gtk_text_buffer_insert (config->db_textbuffer, &current, " ", -1);
-			if (gnome_db_table_field_is_pkey_part (field)) 
-				str = gnome_db_table_field_is_pkey_alone (field) ? _("Primary key") : 
+			if (gda_dict_field_is_pkey_part (field)) 
+				str = gda_dict_field_is_pkey_alone (field) ? _("Primary key") : 
 					_("Part of primary key");
 			else
 				str = _("No");
@@ -942,8 +1020,8 @@ tables_selection_changed_cb (GnomeDbSelector *mgsel, GObject *obj, BrowserConfig
 
 			gtk_text_buffer_insert (config->db_textbuffer, &current, _("Foreign key:"), -1);
 			gtk_text_buffer_insert (config->db_textbuffer, &current, " ", -1);
-			if (gnome_db_table_field_is_fkey_part (field)) 
-				str = gnome_db_table_field_is_fkey_alone (field) ? _("Foreign key") : 
+			if (gda_dict_field_is_fkey_part (field)) 
+				str = gda_dict_field_is_fkey_alone (field) ? _("Foreign key") : 
 					_("Part of foreign key");
 			else
 				str = _("No");
@@ -953,7 +1031,7 @@ tables_selection_changed_cb (GnomeDbSelector *mgsel, GObject *obj, BrowserConfig
 	}
 
 
-	gtk_widget_set_sensitive (config->db_view_contents, obj && IS_GNOME_DB_TABLE (obj));
+	gtk_widget_set_sensitive (config->db_view_contents, obj && GDA_IS_DICT_TABLE (obj));
 }
 
 
@@ -961,44 +1039,46 @@ static void dialog_exec_response_cb (GtkDialog *dlg, gint response, GObject *obj
 static void
 table_view_contents (GtkWidget *button, BrowserConfig *config)
 {
-	GnomeDbQuery *query;
-	GnomeDbTable *table;
-	GnomeDbTarget *target;
-	GnomeDbQfield *field;
+	GdaQuery *query;
+	GdaDictTable *table;
+	GdaQueryTarget *target;
+	GdaQueryField *field;
 	GObject *sel;
 	GtkWidget *grid, *dlg;
 	gchar *str;
 
 	sel = gnome_db_selector_get_selected_object (GNOME_DB_SELECTOR (config->db_selector));
-	if (!sel || !IS_GNOME_DB_TABLE (sel))
+	if (!sel || !GDA_IS_DICT_TABLE (sel))
 		return;
 
-	table = GNOME_DB_TABLE (sel);
+	table = GDA_DICT_TABLE (sel);
 	dlg = g_object_get_data (G_OBJECT (table), "contents");
 
 	if (!dlg) {
+		GdaDataModel *query_model;
+
 		/* Query preparation: "SELECT * FROM table" */
-		query = GNOME_DB_QUERY (gnome_db_query_new (config->dict));
-		gnome_db_query_set_query_type (query, GNOME_DB_QUERY_TYPE_SELECT);
+		query = GDA_QUERY (gda_query_new (config->dict));
+		gda_query_set_query_type (query, GDA_QUERY_TYPE_SELECT);
 		
-		target = GNOME_DB_TARGET (gnome_db_target_new_with_entity (query, GNOME_DB_ENTITY (table)));
-		gnome_db_query_add_target (query, target, NULL);
+		target = GDA_QUERY_TARGET (gda_query_target_new (query, gda_object_get_name (GDA_OBJECT (table))));
+		gda_query_add_target (query, target, NULL);
 		g_object_unref (G_OBJECT (target));
 		
-		field = GNOME_DB_QFIELD (gnome_db_qf_all_new_with_target (query, target));;
-		gnome_db_entity_add_field (GNOME_DB_ENTITY (query), GNOME_DB_FIELD (field));
+		field = GDA_QUERY_FIELD (gda_query_field_all_new (query, gda_object_get_name (GDA_OBJECT (table))));;
+		gda_entity_add_field (GDA_ENTITY (query), GDA_ENTITY_FIELD (field));
 		g_object_unref (G_OBJECT (field));
 		
 		
 		/* Grid */
-		if (gnome_db_table_is_view (table)) {
-			str = g_strdup_printf (_("Contents of view '%s'"), gnome_db_base_get_name (GNOME_DB_BASE (table)));
-			grid = gnome_db_grid_new_with_select_query (query, NULL);
-		}
-		else {
-			str = g_strdup_printf (_("Contents of table '%s'"), gnome_db_base_get_name (GNOME_DB_BASE (table)));
-			grid = gnome_db_grid_new_with_select_query (query, target);
-		}
+		query_model = gda_data_model_query_new (query);
+		if (gda_dict_table_is_view (table)) 
+			str = g_strdup_printf (_("Contents of view '%s'"), gda_object_get_name (GDA_OBJECT (table)));
+		else 
+			str = g_strdup_printf (_("Contents of table '%s'"), gda_object_get_name (GDA_OBJECT (table)));
+		grid = gnome_db_grid_new (query_model);
+		g_object_unref (query_model);
+
 		g_object_set (G_OBJECT (grid), "title_string", str, NULL);
 		dlg = gtk_dialog_new_with_buttons (str, GTK_WINDOW (config->mainwin), 0,
 						   GTK_STOCK_CLOSE,
@@ -1009,12 +1089,6 @@ table_view_contents (GtkWidget *button, BrowserConfig *config)
 		
 		gtk_widget_show_all (dlg);
 		gnome_db_grid_set_sample_size (GNOME_DB_GRID (grid), 300);
-		gnome_db_data_widget_set_mode (GNOME_DB_DATA_WIDGET (grid),
-                                               GNOME_DB_ACTION_ASK_CONFIRM_UPDATE |
-                                               GNOME_DB_ACTION_ASK_CONFIRM_DELETE |
-                                               GNOME_DB_ACTION_ASK_CONFIRM_INSERT |
-                                               GNOME_DB_ACTION_REPORT_ERROR |
-                                               GNOME_DB_ACTION_NAVIGATION_ARROWS);
 
 		g_object_unref (G_OBJECT (query));
 		g_object_set_data (G_OBJECT (table), "contents", dlg);
