@@ -1,5 +1,5 @@
 /* GNOME DB library
- * Copyright (C) 1999 - 2005 The GNOME Foundation.
+ * Copyright (C) 1999 - 2006 The GNOME Foundation.
  *
  * AUTHORS:
  *      Rodrigo Moya <rodrigo@gnome-db.org>
@@ -224,16 +224,40 @@ add_dsn_cb (GtkButton *button, GnomeDbLogin *login)
 	gtk_widget_show (dialog);
 }
 
+static void
+dsn_entry_changed_cb (GnomeDbDataSourceSelector *sel, GnomeDbLogin *login)
+{
+	gchar *dsn;
+	GdaDataSourceInfo *info = NULL;
+
+	dsn = gnome_db_option_menu_get_selection (GTK_OPTION_MENU (sel));
+	info = gda_config_find_data_source (dsn);
+
+	gtk_entry_set_text (GTK_ENTRY (login->priv->username_entry), "");
+	gtk_entry_set_text (GTK_ENTRY (login->priv->password_entry), "");
+
+	if (info) {
+		if (info->username)
+			gtk_entry_set_text (GTK_ENTRY (login->priv->username_entry), info->username);
+		if (info->password)
+			gtk_entry_set_text (GTK_ENTRY (login->priv->password_entry), info->password);
+		gda_data_source_info_free (info);
+	}
+}
+
 static GtkWidget *
 gnome_db_login_construct (GnomeDbLogin *login, const gchar *dsn)
 {
 	GtkWidget *table;
 	GtkWidget *label;
+	GdaDataSourceInfo *info = NULL;
 
 	g_return_val_if_fail (GNOME_DB_IS_LOGIN (login), GTK_WIDGET (login));
 
-	if (dsn != NULL)
+	if (dsn != NULL) {
 		login->priv->dsn_name = g_strdup (dsn);
+		info = gda_config_find_data_source (dsn);
+	}
 	else
 		login->priv->dsn_name = NULL;
 
@@ -250,6 +274,8 @@ gnome_db_login_construct (GnomeDbLogin *login, const gchar *dsn)
 	gtk_widget_show (login->priv->dsn_entry);
 	gtk_table_attach (GTK_TABLE (table), login->priv->dsn_entry, 1, 2, 0, 1,
 			  GTK_FILL | GTK_EXPAND | GTK_SHRINK, GTK_FILL, 0, 0);
+	g_signal_connect (G_OBJECT (login->priv->dsn_entry), "changed",
+			  G_CALLBACK (dsn_entry_changed_cb), login);
 
 	login->priv->create_dsn_button = gnome_db_new_button_widget_from_stock (GTK_STOCK_ADD);
 	g_signal_connect (G_OBJECT (login->priv->create_dsn_button), "clicked",
@@ -265,7 +291,7 @@ gnome_db_login_construct (GnomeDbLogin *login, const gchar *dsn)
 	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
 	login->priv->username_entry = gnome_db_new_entry_widget (0, TRUE);
 	gtk_table_attach (GTK_TABLE (table), login->priv->username_entry, 1, 3, 1, 2,
-			  GTK_FILL | GTK_EXPAND | GTK_SHRINK, GTK_FILL, 0, 0);
+			  GTK_FILL | GTK_EXPAND | GTK_SHRINK, GTK_FILL, 0, 0);			
 
 	label = gnome_db_new_label_widget (_("Password:"));
         gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
@@ -277,6 +303,14 @@ gnome_db_login_construct (GnomeDbLogin *login, const gchar *dsn)
 	gtk_table_attach (GTK_TABLE (table), login->priv->password_entry, 1, 3, 2, 3,
 			  GTK_FILL | GTK_EXPAND | GTK_SHRINK, GTK_FILL, 0, 0);
 
+	if (info) {
+		if (info->username)
+			gtk_entry_set_text (GTK_ENTRY (login->priv->username_entry), info->username);
+		if (info->password)
+			gtk_entry_set_text (GTK_ENTRY (login->priv->password_entry), info->password);
+		gda_data_source_info_free (info);
+	}
+
 	return GTK_WIDGET (login);
 }
 
