@@ -1,8 +1,9 @@
 /* GNOME DB library
- * Copyright (C) 1999-2002 The GNOME Foundation.
+ * Copyright (C) 1999 - 2004 The GNOME Foundation.
  *
  * AUTHORS:
  *      Rodrigo Moya <rodrigo@gnome-db.org>
+ *      Vivien Malerba <malerba@gnome-db.org>
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -20,8 +21,8 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#if !defined(__gnome_db_login_h__)
-#  define __gnome_db_login_h__
+#ifndef __GNOME_DB_LOGIN_H__
+#define __GNOME_DB_LOGIN_H__
 
 #include <gtk/gtkvbox.h>
 
@@ -46,16 +47,17 @@ struct _GnomeDbLoginClass {
 	GtkVBoxClass parent_class;
 };
 
-GType        gnome_db_login_get_type (void);
-GtkWidget   *gnome_db_login_new (const gchar *dsn);
-const gchar *gnome_db_login_get_dsn (GnomeDbLogin *login);
-void         gnome_db_login_set_dsn (GnomeDbLogin *login, const gchar *dsn);
-const gchar *gnome_db_login_get_username (GnomeDbLogin *login);
-void         gnome_db_login_set_username (GnomeDbLogin *login, const gchar *username);
-const gchar *gnome_db_login_get_password (GnomeDbLogin *login);
-void         gnome_db_login_set_password (GnomeDbLogin *login, const gchar *password);
+GType        gnome_db_login_get_type                 (void);
+GtkWidget   *gnome_db_login_new                      (const gchar *dsn);
+const gchar *gnome_db_login_get_dsn                  (GnomeDbLogin *login);
+void         gnome_db_login_set_dsn                  (GnomeDbLogin *login, const gchar *dsn);
+const gchar *gnome_db_login_get_username             (GnomeDbLogin *login);
+void         gnome_db_login_set_username             (GnomeDbLogin *login, const gchar *username);
+const gchar *gnome_db_login_get_password             (GnomeDbLogin *login);
+void         gnome_db_login_set_password             (GnomeDbLogin *login, const gchar *password);
 
 void         gnome_db_login_set_enable_create_button (GnomeDbLogin *login, gboolean enable);
+void         gnome_db_login_set_show_dsn_selector    (GnomeDbLogin *login, gboolean show);
 
 G_END_DECLS
 
