@@ -1,6 +1,6 @@
 /* gnome-db-canvas-join.c
  *
- * Copyright (C) 2004 - 2005 Vivien Malerba
+ * Copyright (C) 2004 - 2006 Vivien Malerba
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -19,16 +19,12 @@
  */
 
 #include <gtk/gtk.h>
+#include <libgda/libgda.h>
+#include <glib/gi18n-lib.h>
 #include "gnome-db-canvas.h"
 #include "gnome-db-canvas-join.h"
 #include "gnome-db-canvas-entity.h"
 #include "gnome-db-canvas-text.h"
-#include <libgnomedb/gnome-db-join.h>
-#include <libgnomedb/gnome-db-qf-field.h>
-#include <libgnomedb/gnome-db-referer.h>
-#include <libgnomedb/gnome-db-renderer.h>
-#include <libgnomedb/gnome-db-condition.h>
-#include <libgnomedb/gnome-db-target.h>
 #include "graph-utility.h"
 
 static void gnome_db_canvas_join_class_init (GnomeDbCanvasJoinClass * class);
@@ -36,16 +32,16 @@ static void gnome_db_canvas_join_init       (GnomeDbCanvasJoin * cc);
 static void gnome_db_canvas_join_dispose    (GObject   * object);
 static void gnome_db_canvas_join_finalize   (GObject   * object);
 
-static void gnome_db_canvas_join_set_property    (GObject              *object,
-					    guint                 param_id,
-					    const GValue         *value,
-					    GParamSpec           *pspec);
-static void gnome_db_canvas_join_get_property    (GObject              *object,
-					    guint                 param_id,
-					    GValue               *value,
-					    GParamSpec           *pspec);
+static void gnome_db_canvas_join_set_property    (GObject *object,
+					    guint param_id,
+					    const GValue *value,
+					    GParamSpec *pspec);
+static void gnome_db_canvas_join_get_property    (GObject *object,
+					    guint param_id,
+					    GValue *value,
+					    GParamSpec *pspec);
 
-static void gnome_db_canvas_join_set_join (GnomeDbCanvasJoin *cc, GnomeDbJoin *join);
+static void gnome_db_canvas_join_set_join (GnomeDbCanvasJoin *cc, GdaQueryJoin *join);
 static void clean_items (GnomeDbCanvasJoin *cc);
 static void create_items (GnomeDbCanvasJoin *cc);
 
@@ -57,7 +53,7 @@ enum
 
 struct _GnomeDbCanvasJoinPrivate
 {
-	GnomeDbJoin           *join;
+	GdaQueryJoin           *join;
 	GnomeDbCanvasEntity   *target1_entity;
 	GnomeDbCanvasEntity   *target2_entity;
 };
@@ -65,7 +61,7 @@ struct _GnomeDbCanvasJoinPrivate
 /* get a pointer to the parents to be able to call their destructor */
 static GObjectClass *parent_class = NULL;
 
-guint
+GType
 gnome_db_canvas_join_get_type (void)
 {
 	static GType type = 0;
@@ -83,7 +79,7 @@ gnome_db_canvas_join_get_type (void)
 			(GInstanceInitFunc) gnome_db_canvas_join_init
 		};		
 
-		type = g_type_register_static (GNOME_DB_CANVAS_ITEM_TYPE, "GnomeDbCanvasJoin", &info, 0);
+		type = g_type_register_static (GNOME_DB_TYPE_CANVAS_ITEM, "GnomeDbCanvasJoin", &info, 0);
 	}
 
 	return type;
@@ -119,8 +115,8 @@ gnome_db_canvas_join_init (GnomeDbCanvasJoin *cc)
 
 
 static void entity_destroy_cb (GnomeDbCanvasEntity *entity, GnomeDbCanvasJoin *cc);
-static void join_nullified_cb (GnomeDbJoin *join, GnomeDbCanvasJoin *cc);
-static void join_changed_cb (GnomeDbJoin *join, GnomeDbCanvasJoin *cc);
+static void join_destroyed_cb (GdaQueryJoin *join, GnomeDbCanvasJoin *cc);
+static void join_changed_cb (GdaQueryJoin *join, GnomeDbCanvasJoin *cc);
 
 static void
 gnome_db_canvas_join_dispose (GObject *object)
@@ -134,7 +130,7 @@ gnome_db_canvas_join_dispose (GObject *object)
 	clean_items (cc);
 	if (cc->priv->join) {
 		g_signal_handlers_disconnect_by_func (G_OBJECT (cc->priv->join),
-						      G_CALLBACK (join_nullified_cb), cc);
+						      G_CALLBACK (join_destroyed_cb), cc);
 		g_signal_handlers_disconnect_by_func (G_OBJECT (cc->priv->join),
 						      G_CALLBACK (join_changed_cb), cc);
 		cc->priv->join = NULL;
@@ -146,7 +142,7 @@ gnome_db_canvas_join_dispose (GObject *object)
 
 
 static void
-gnome_db_canvas_join_finalize (GObject  *object)
+gnome_db_canvas_join_finalize (GObject *object)
 {
 	GnomeDbCanvasJoin *cc;
 	g_return_if_fail (object != NULL);
@@ -163,10 +159,10 @@ gnome_db_canvas_join_finalize (GObject  *object)
 }
 
 static void 
-gnome_db_canvas_join_set_property    (GObject              *object,
-				guint                 param_id,
-				const GValue         *value,
-				GParamSpec           *pspec)
+gnome_db_canvas_join_set_property    (GObject *object,
+				guint param_id,
+				const GValue *value,
+				GParamSpec *pspec)
 {
 	GnomeDbCanvasJoin *cc;
 
@@ -174,16 +170,16 @@ gnome_db_canvas_join_set_property    (GObject              *object,
 
 	switch (param_id) {
 	case PROP_JOIN:
-		gnome_db_canvas_join_set_join (cc, (GnomeDbJoin *) g_value_get_pointer (value));
+		gnome_db_canvas_join_set_join (cc, (GdaQueryJoin *) g_value_get_pointer (value));
 		break;
 	}
 }
 
 static void 
-gnome_db_canvas_join_get_property    (GObject              *object,
-				guint                 param_id,
-				GValue               *value,
-				GParamSpec           *pspec)
+gnome_db_canvas_join_get_property    (GObject *object,
+				guint param_id,
+				GValue *value,
+				GParamSpec *pspec)
 {
 	GnomeDbCanvasJoin *cc;
 
@@ -197,13 +193,13 @@ gnome_db_canvas_join_get_property    (GObject              *object,
 }
 
 static void
-join_nullified_cb (GnomeDbJoin *join, GnomeDbCanvasJoin *cc)
+join_destroyed_cb (GdaQueryJoin *join, GnomeDbCanvasJoin *cc)
 {
 	gtk_object_destroy (GTK_OBJECT (cc));	
 }
 
 static void
-join_changed_cb (GnomeDbJoin *join, GnomeDbCanvasJoin *cc)
+join_changed_cb (GdaQueryJoin *join, GnomeDbCanvasJoin *cc)
 {
 	clean_items (cc);
 	create_items (cc);
@@ -254,29 +250,29 @@ static void
 create_items (GnomeDbCanvasJoin *cc)
 {
 	GnomeCanvasItem *item;
-	GnomeDbCondition *cond;
+	GdaQueryCondition *cond;
 	gboolean cond_is_strict = FALSE;
 	GnomeDbCanvasItem *entity_item;
 	GnomeDbCanvas *canvas = gnome_db_canvas_item_get_canvas (GNOME_DB_CANVAS_ITEM (cc));
-	GnomeDbTarget *target1, *target2;
+	GdaQueryTarget *target1, *target2;
 	GSList *items, *list;
-	GnomeDbJoinType join_type;
+	GdaQueryJoinType join_type;
 	guint extra_mode = 0;
 
 	if (!cc->priv->join)
 		return;
 
-	cond = gnome_db_join_get_condition (cc->priv->join);
+	cond = gda_query_join_get_condition (cc->priv->join);
 	if (cond) 
-		cond_is_strict = gnome_db_condition_represents_join_strict (cond, NULL, NULL);
+		cond_is_strict = gda_query_condition_represents_join_strict (cond, NULL, NULL);
 	
 	/* Analyse Join */
 	item = GNOME_CANVAS_ITEM (cc);
-	target1 = gnome_db_join_get_target_1 (cc->priv->join);
-	entity_item = gnome_db_canvas_get_item_for_object (canvas, GNOME_DB_BASE (target1));
+	target1 = gda_query_join_get_target_1 (cc->priv->join);
+	entity_item = gnome_db_canvas_get_item_for_object (canvas, GDA_OBJECT (target1));
 	if (!entity_item) {
 		g_warning ("Can't find GnomeDbCanvasItem object for a join target '%s'; perhaps you forgot to "
-			   "call gnome_db_graph_query_sync_targets()?", gnome_db_base_get_name (GNOME_DB_BASE (target1)));
+			   "call gda_graph_query_sync_targets()?", gda_object_get_name (GDA_OBJECT (target1)));
 		return;
 	}
 	cc->priv->target1_entity = GNOME_DB_CANVAS_ENTITY (entity_item);
@@ -289,11 +285,11 @@ create_items (GnomeDbCanvasJoin *cc)
 	g_signal_connect (G_OBJECT (entity_item), "destroy",
 			  G_CALLBACK (entity_destroy_cb), cc);
 
-	target2 = gnome_db_join_get_target_2 (cc->priv->join);
-	entity_item = gnome_db_canvas_get_item_for_object (canvas, GNOME_DB_BASE (target2));
+	target2 = gda_query_join_get_target_2 (cc->priv->join);
+	entity_item = gnome_db_canvas_get_item_for_object (canvas, GDA_OBJECT (target2));
 	if (!entity_item) {
 		g_warning ("Can't find GnomeDbCanvasItem object for a join target '%s'; perhaps you forgot to "
-			   "call gnome_db_graph_query_sync_targets()?", gnome_db_base_get_name (GNOME_DB_BASE (target2)));
+			   "call gda_graph_query_sync_targets()?", gda_object_get_name (GDA_OBJECT (target2)));
 		return;
 	}
 	cc->priv->target2_entity = GNOME_DB_CANVAS_ENTITY (entity_item);
@@ -306,15 +302,15 @@ create_items (GnomeDbCanvasJoin *cc)
 	g_signal_connect (G_OBJECT (entity_item), "destroy",
 			  G_CALLBACK (entity_destroy_cb), cc);
 
-	join_type = gnome_db_join_get_join_type (cc->priv->join);
+	join_type = gda_query_join_get_join_type (cc->priv->join);
 	switch (join_type) {
-	case GNOME_DB_JOIN_TYPE_LEFT_OUTER:
+	case GDA_QUERY_JOIN_TYPE_LEFT_OUTER:
 		extra_mode = CANVAS_SHAPE_EXT_JOIN_OUTER_1;
 		break;
-	case GNOME_DB_JOIN_TYPE_RIGHT_OUTER:
+	case GDA_QUERY_JOIN_TYPE_RIGHT_OUTER:
 		extra_mode = CANVAS_SHAPE_EXT_JOIN_OUTER_2;
 		break;
-	case GNOME_DB_JOIN_TYPE_FULL_OUTER:
+	case GDA_QUERY_JOIN_TYPE_FULL_OUTER:
 		extra_mode = CANVAS_SHAPE_EXT_JOIN_OUTER_1 | CANVAS_SHAPE_EXT_JOIN_OUTER_2;
 	default:
 		break;
@@ -326,21 +322,21 @@ create_items (GnomeDbCanvasJoin *cc)
 		gint nb_scond;
 		GSList *condlist, *canvas_shapes, *clist;
 
-		condlist = gnome_db_condition_get_main_conditions (cond);
+		condlist = gda_query_condition_get_main_conditions (cond);
 		nb_scond = g_slist_length (condlist);
 		clist = condlist;
 		while (clist) {
-			GnomeDbCondition *scond = GNOME_DB_CONDITION (clist->data);
-			GnomeDbTarget *t;
-			GnomeDbField *f1, *f2;
-			GnomeDbQfield *tmp;
+			GdaQueryCondition *scond = GDA_QUERY_CONDITION (clist->data);
+			GdaQueryTarget *t;
+			GdaEntityField *f1, *f2;
+			GdaQueryField *tmp;
 
-			g_assert (gnome_db_condition_get_cond_type (scond) == GNOME_DB_CONDITION_LEAF_EQUAL);
-			tmp =  gnome_db_condition_leaf_get_operator (scond, GNOME_DB_CONDITION_OP_LEFT);
-			f1 = gnome_db_qf_field_get_ref_field (GNOME_DB_QF_FIELD (tmp));
-			t = gnome_db_qf_field_get_target (GNOME_DB_QF_FIELD (tmp));
-			tmp =  gnome_db_condition_leaf_get_operator (scond, GNOME_DB_CONDITION_OP_RIGHT);
-			f2 = gnome_db_qf_field_get_ref_field (GNOME_DB_QF_FIELD (tmp));
+			g_assert (gda_query_condition_get_cond_type (scond) == GDA_QUERY_CONDITION_LEAF_EQUAL);
+			tmp =  gda_query_condition_leaf_get_operator (scond, GDA_QUERY_CONDITION_OP_LEFT);
+			f1 = gda_query_field_field_get_ref_field (GDA_QUERY_FIELD_FIELD (tmp));
+			t = gda_query_field_field_get_target (GDA_QUERY_FIELD_FIELD (tmp));
+			tmp =  gda_query_condition_leaf_get_operator (scond, GDA_QUERY_CONDITION_OP_RIGHT);
+			f2 = gda_query_field_field_get_ref_field (GDA_QUERY_FIELD_FIELD (tmp));
 
 			if (t == target1)
 				canvas_shapes = graph_util_compute_connect_shapes (cc->priv->target1_entity, f1,
@@ -404,7 +400,7 @@ static void popup_join_properties_cb (GtkMenuItem *mitem, GnomeDbCanvasJoin *cc)
 static gboolean
 single_item_event_cb (GnomeCanvasItem *ci, GdkEvent *event, GnomeDbCanvasJoin *cc)
 {
-	GnomeDbCondition *cond = g_object_get_data (G_OBJECT (ci), "cond");
+	GdaQueryCondition *cond = g_object_get_data (G_OBJECT (ci), "cond");
 	GtkWidget *menu, *entry;
 	gboolean done = FALSE;
 	GList *list;
@@ -474,13 +470,13 @@ single_item_event_cb (GnomeCanvasItem *ci, GdkEvent *event, GnomeDbCanvasJoin *c
 	return done;
 }
 
-static const gchar *join_type_to_char (GnomeDbJoinType type);
-static void dlg_join_nullified_cb (GnomeDbJoin *join, GtkDialog *dlg) ;
-static void change_join_type_cb (GtkToggleButton *rb, GnomeDbJoin *join);
-static void change_join_cond_cb (GtkButton *button, GnomeDbJoin *join);
-static void change_join_cond_fkcons_cb (GtkButton *button, GnomeDbJoin *join);
-static void join_properties_type_changed_cb (GnomeDbJoin *join, GtkDialog *dlg);
-static void join_properties_condition_changed_cb (GnomeDbJoin *join, GtkDialog *dlg);
+static const gchar *join_type_to_char (GdaQueryJoinType type);
+static void dlg_join_destroyed_cb (GdaQueryJoin *join, GtkDialog *dlg) ;
+static void change_join_type_cb (GtkToggleButton *rb, GdaQueryJoin *join);
+static void change_join_cond_cb (GtkButton *button, GdaQueryJoin *join);
+static void change_join_cond_fkcons_cb (GtkButton *button, GdaQueryJoin *join);
+static void join_properties_type_changed_cb (GdaQueryJoin *join, GtkDialog *dlg);
+static void join_properties_condition_changed_cb (GdaQueryJoin *join, GtkDialog *dlg);
 static void
 popup_join_properties_cb (GtkMenuItem *mitem, GnomeDbCanvasJoin *cc)
 {
@@ -521,36 +517,36 @@ popup_join_properties_cb (GtkMenuItem *mitem, GnomeDbCanvasJoin *cc)
 	rb = gtk_radio_button_new_with_label (NULL, _("Inner join"));
 	gtk_table_attach_defaults (GTK_TABLE (table), rb, 0, 1, 0, 1);
 	gtk_widget_show (rb);
-	g_object_set_data (G_OBJECT (dlg), join_type_to_char (GNOME_DB_JOIN_TYPE_INNER), rb);
-	g_object_set_data (G_OBJECT (rb), "type", GINT_TO_POINTER (GNOME_DB_JOIN_TYPE_INNER));
+	g_object_set_data (G_OBJECT (dlg), join_type_to_char (GDA_QUERY_JOIN_TYPE_INNER), rb);
+	g_object_set_data (G_OBJECT (rb), "type", GINT_TO_POINTER (GDA_QUERY_JOIN_TYPE_INNER));
 	g_signal_connect (G_OBJECT (rb), "toggled", G_CALLBACK (change_join_type_cb), cc->priv->join);
 
 	rb2 = gtk_radio_button_new_with_label_from_widget (GTK_RADIO_BUTTON (rb), _("Left outer join"));
 	gtk_table_attach_defaults (GTK_TABLE (table), rb2, 0, 1, 1, 2);
 	gtk_widget_show (rb2);
-	g_object_set_data (G_OBJECT (dlg), join_type_to_char (GNOME_DB_JOIN_TYPE_LEFT_OUTER), rb2);
-	g_object_set_data (G_OBJECT (rb2), "type", GINT_TO_POINTER (GNOME_DB_JOIN_TYPE_LEFT_OUTER));
+	g_object_set_data (G_OBJECT (dlg), join_type_to_char (GDA_QUERY_JOIN_TYPE_LEFT_OUTER), rb2);
+	g_object_set_data (G_OBJECT (rb2), "type", GINT_TO_POINTER (GDA_QUERY_JOIN_TYPE_LEFT_OUTER));
 	g_signal_connect (G_OBJECT (rb2), "toggled", G_CALLBACK (change_join_type_cb), cc->priv->join);
 
 	rb2 = gtk_radio_button_new_with_label_from_widget (GTK_RADIO_BUTTON (rb), _("Right outer join"));
 	gtk_table_attach_defaults (GTK_TABLE (table), rb2, 0, 1, 2, 3);
 	gtk_widget_show (rb2);
-	g_object_set_data (G_OBJECT (dlg), join_type_to_char (GNOME_DB_JOIN_TYPE_RIGHT_OUTER), rb2);
-	g_object_set_data (G_OBJECT (rb2), "type", GINT_TO_POINTER (GNOME_DB_JOIN_TYPE_RIGHT_OUTER));
+	g_object_set_data (G_OBJECT (dlg), join_type_to_char (GDA_QUERY_JOIN_TYPE_RIGHT_OUTER), rb2);
+	g_object_set_data (G_OBJECT (rb2), "type", GINT_TO_POINTER (GDA_QUERY_JOIN_TYPE_RIGHT_OUTER));
 	g_signal_connect (G_OBJECT (rb2), "toggled", G_CALLBACK (change_join_type_cb), cc->priv->join);
 
 	rb2 = gtk_radio_button_new_with_label_from_widget (GTK_RADIO_BUTTON (rb), _("Full outer join"));
 	gtk_table_attach_defaults (GTK_TABLE (table), rb2, 0, 1, 3, 4);
 	gtk_widget_show (rb2);
-	g_object_set_data (G_OBJECT (dlg), join_type_to_char (GNOME_DB_JOIN_TYPE_FULL_OUTER), rb2);
-	g_object_set_data (G_OBJECT (rb2), "type", GINT_TO_POINTER (GNOME_DB_JOIN_TYPE_FULL_OUTER));
+	g_object_set_data (G_OBJECT (dlg), join_type_to_char (GDA_QUERY_JOIN_TYPE_FULL_OUTER), rb2);
+	g_object_set_data (G_OBJECT (rb2), "type", GINT_TO_POINTER (GDA_QUERY_JOIN_TYPE_FULL_OUTER));
 	g_signal_connect (G_OBJECT (rb2), "toggled", G_CALLBACK (change_join_type_cb), cc->priv->join);
 
 	rb2 = gtk_radio_button_new_with_label_from_widget (GTK_RADIO_BUTTON (rb), _("Cross join"));
 	gtk_table_attach_defaults (GTK_TABLE (table), rb2, 0, 1, 4, 5);
 	gtk_widget_show (rb2);
-	g_object_set_data (G_OBJECT (dlg), join_type_to_char (GNOME_DB_JOIN_TYPE_CROSS), rb2);
-	g_object_set_data (G_OBJECT (rb2), "type", GINT_TO_POINTER (GNOME_DB_JOIN_TYPE_CROSS));
+	g_object_set_data (G_OBJECT (dlg), join_type_to_char (GDA_QUERY_JOIN_TYPE_CROSS), rb2);
+	g_object_set_data (G_OBJECT (rb2), "type", GINT_TO_POINTER (GDA_QUERY_JOIN_TYPE_CROSS));
 	g_signal_connect (G_OBJECT (rb2), "toggled", G_CALLBACK (change_join_type_cb), cc->priv->join);
 
 	label = gtk_label_new ("");
@@ -613,7 +609,7 @@ popup_join_properties_cb (GtkMenuItem *mitem, GnomeDbCanvasJoin *cc)
 	join_properties_type_changed_cb (cc->priv->join, GTK_DIALOG (dlg));
 	join_properties_condition_changed_cb (cc->priv->join, GTK_DIALOG (dlg));
 
-	gnome_db_base_connect_nullify (cc->priv->join, G_CALLBACK (dlg_join_nullified_cb), dlg);
+	gda_object_connect_destroy (cc->priv->join, G_CALLBACK (dlg_join_destroyed_cb), dlg);
 	g_signal_connect (G_OBJECT (cc->priv->join), "type_changed",
 			  G_CALLBACK (join_properties_type_changed_cb), dlg);
 	g_signal_connect (G_OBJECT (cc->priv->join), "condition_changed",
@@ -624,7 +620,7 @@ popup_join_properties_cb (GtkMenuItem *mitem, GnomeDbCanvasJoin *cc)
 	gtk_widget_destroy (dlg);
 
 	g_signal_handlers_disconnect_by_func (G_OBJECT (cc->priv->join),
-					      G_CALLBACK (dlg_join_nullified_cb), dlg);
+					      G_CALLBACK (dlg_join_destroyed_cb), dlg);
 	g_signal_handlers_disconnect_by_func (G_OBJECT (cc->priv->join),
 					      G_CALLBACK (join_properties_type_changed_cb), dlg);
 	g_signal_handlers_disconnect_by_func (G_OBJECT (cc->priv->join),
@@ -632,25 +628,25 @@ popup_join_properties_cb (GtkMenuItem *mitem, GnomeDbCanvasJoin *cc)
 }
 
 static void
-dlg_join_nullified_cb (GnomeDbJoin *join, GtkDialog *dlg) 
+dlg_join_destroyed_cb (GdaQueryJoin *join, GtkDialog *dlg) 
 {
 	gtk_dialog_response (dlg, 0);
 }
 
 static void
-change_join_type_cb (GtkToggleButton *rb, GnomeDbJoin *join)
+change_join_type_cb (GtkToggleButton *rb, GdaQueryJoin *join)
 {
 	/* only modify the model (join type), no widget modification */
-	GnomeDbJoinType type = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (rb), "type"));
+	GdaQueryJoinType type = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (rb), "type"));
 
 	if (gtk_toggle_button_get_active (rb))
-		gnome_db_join_set_join_type (join, type);
+		gda_query_join_set_join_type (join, type);
 }
 
 static void
-change_join_cond_fkcons_cb (GtkButton *button, GnomeDbJoin *join)
+change_join_cond_fkcons_cb (GtkButton *button, GdaQueryJoin *join)
 {
-	if (!gnome_db_join_set_condition_from_fkcons (join)) {
+	if (!gda_query_join_set_condition_from_fkcons (join)) {
 		GtkWidget *dlg;
 		gchar *msg = g_strdup_printf ("<big>%s</big>\n\n%s",
 					      _("Could not propose a join condition:"),
@@ -665,12 +661,12 @@ change_join_cond_fkcons_cb (GtkButton *button, GnomeDbJoin *join)
 	}
 
 #ifdef debug
-	gnome_db_base_dump (GNOME_DB_BASE (gnome_db_join_get_query (join)), 0);
+	gda_object_dump (GDA_OBJECT (gda_query_join_get_query (join)), 0);
 #endif
 }
 
 static void
-change_join_cond_cb (GtkButton *button, GnomeDbJoin *join)
+change_join_cond_cb (GtkButton *button, GdaQueryJoin *join)
 {
 	/* only modify the model (join condition), no widget modification */
 	GtkWidget *wid;
@@ -686,7 +682,7 @@ change_join_cond_cb (GtkButton *button, GnomeDbJoin *join)
 	str = gtk_text_buffer_get_text (buffer, &start, &end, FALSE);
 	if (str && *str) {
 		/* set join condition from SQL */
-		if (!gnome_db_join_set_condition_from_sql (join, str, &error)) {
+		if (!gda_query_join_set_condition_from_sql (join, str, &error)) {
 			GtkWidget *dlg;
 			gchar *msg = g_strdup_printf ("<big>%s</big>\n\n%s",
 						      _("Could not set the new join condition:"),
@@ -705,18 +701,18 @@ change_join_cond_cb (GtkButton *button, GnomeDbJoin *join)
 	g_free (str);
 
 #ifdef debug
-	gnome_db_base_dump (GNOME_DB_BASE (gnome_db_join_get_query (join)), 0);
+	gda_object_dump (GDA_OBJECT (gda_query_join_get_query (join)), 0);
 #endif
 }
 
 static void
-join_properties_type_changed_cb (GnomeDbJoin *join, GtkDialog *dlg)
+join_properties_type_changed_cb (GdaQueryJoin *join, GtkDialog *dlg)
 {
 	gchar *str = NULL;
 	gchar *t1name, *t2name;
 	GtkWidget *label, *wid;
 	gboolean sensitive;
-	GnomeDbJoinType type = gnome_db_join_get_join_type (join);
+	GdaQueryJoinType type = gda_query_join_get_join_type (join);
 
 	/* selected radio button */
 	wid = g_object_get_data (G_OBJECT (dlg), join_type_to_char (type));
@@ -725,33 +721,33 @@ join_properties_type_changed_cb (GnomeDbJoin *join, GtkDialog *dlg)
 	g_signal_handlers_unblock_by_func (G_OBJECT (wid), G_CALLBACK (change_join_type_cb), join);
 
 	/* explanation text */
-	t1name = gnome_db_target_get_complete_name (gnome_db_join_get_target_1 (join));
-	t2name = gnome_db_target_get_complete_name (gnome_db_join_get_target_2 (join));
+	t1name = gda_query_target_get_complete_name (gda_query_join_get_target_1 (join));
+	t2name = gda_query_target_get_complete_name (gda_query_join_get_target_2 (join));
 
 	switch (type) {
-	case GNOME_DB_JOIN_TYPE_INNER:
+	case GDA_QUERY_JOIN_TYPE_INNER:
 		str = g_strdup_printf (_("Select only the records of the two targets "
                                          "('%s' and '%s') where the fields respects the "
 					 "join condition."),
                                        t1name, t2name);
 		break;
-	case GNOME_DB_JOIN_TYPE_LEFT_OUTER:
+	case GDA_QUERY_JOIN_TYPE_LEFT_OUTER:
 		str = g_strdup_printf (_("Select all the records of '%s' "
                                          "and those of '%s' where the fields "
                                          "respects the join condition."), t1name, t2name);
 		break;
-	case GNOME_DB_JOIN_TYPE_RIGHT_OUTER:
+	case GDA_QUERY_JOIN_TYPE_RIGHT_OUTER:
 		str = g_strdup_printf (_("Select all the records of '%s' "
                                          "and those of '%s' where the fields "
                                          "respects the join condition."), t2name, t1name);
 		break;
-	case GNOME_DB_JOIN_TYPE_FULL_OUTER:
+	case GDA_QUERY_JOIN_TYPE_FULL_OUTER:
 		str = g_strdup_printf (_("Select all the records of '%s' "
                                          "and those of '%s' linking the two "
                                          "when the fields respects the join condition."), 
 				       t1name, t2name);
 		break;
-	case GNOME_DB_JOIN_TYPE_CROSS:
+	case GDA_QUERY_JOIN_TYPE_CROSS:
 		str = g_strdup_printf (_("Select all the combinations of the records of '%s' "
                                          "and of '%s' without any attempt at linking the two "
                                          "(no join condition applies)."), 
@@ -769,7 +765,7 @@ join_properties_type_changed_cb (GnomeDbJoin *join, GtkDialog *dlg)
 	gtk_label_set_text (GTK_LABEL (label), str);
 	g_free (str);
 
-	sensitive = type != GNOME_DB_JOIN_TYPE_CROSS ? TRUE : FALSE;
+	sensitive = type != GDA_QUERY_JOIN_TYPE_CROSS ? TRUE : FALSE;
 	wid = g_object_get_data (G_OBJECT (dlg), "join_cond_label");
 	gtk_widget_set_sensitive (wid, sensitive);
 	wid = g_object_get_data (G_OBJECT (dlg), "join_cond_box");
@@ -777,20 +773,20 @@ join_properties_type_changed_cb (GnomeDbJoin *join, GtkDialog *dlg)
 }
 
 static void
-join_properties_condition_changed_cb (GnomeDbJoin *join, GtkDialog *dlg)
+join_properties_condition_changed_cb (GdaQueryJoin *join, GtkDialog *dlg)
 {
 	GtkWidget *wid;
 	GtkTextBuffer *buffer;
 	GError *error = NULL;
-	GnomeDbCondition *cond = gnome_db_join_get_condition (join);
+	GdaQueryCondition *cond = gda_query_join_get_condition (join);
 	wid = g_object_get_data (G_OBJECT (dlg), "join_cond_entry");
 
 	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (wid));
 	if (cond) {
 		gchar *str;
 
-		str = gnome_db_renderer_render_as_sql (GNOME_DB_RENDERER (cond), NULL, 
-						 GNOME_DB_RENDERER_EXTRA_PRETTY_SQL | GNOME_DB_RENDERER_EXTRA_VAL_ATTRS, &error);
+		str = gda_renderer_render_as_sql (GDA_RENDERER (cond), NULL, 
+						 GDA_RENDERER_EXTRA_PRETTY_SQL | GDA_RENDERER_EXTRA_VAL_ATTRS, &error);
 		if (str) {
 			gtk_text_buffer_set_text (buffer, str, -1);
 			g_free (str);
@@ -805,18 +801,18 @@ join_properties_condition_changed_cb (GnomeDbJoin *join, GtkDialog *dlg)
 
 
 static const gchar *
-join_type_to_char (GnomeDbJoinType type)
+join_type_to_char (GdaQueryJoinType type)
 {
 	switch (type) {
-	case GNOME_DB_JOIN_TYPE_INNER:
+	case GDA_QUERY_JOIN_TYPE_INNER:
 		return "join_I";
-	case GNOME_DB_JOIN_TYPE_LEFT_OUTER:
+	case GDA_QUERY_JOIN_TYPE_LEFT_OUTER:
 		return "join_L";
-	case GNOME_DB_JOIN_TYPE_RIGHT_OUTER:
+	case GDA_QUERY_JOIN_TYPE_RIGHT_OUTER:
 		return "join_R";
-	case GNOME_DB_JOIN_TYPE_FULL_OUTER:
+	case GDA_QUERY_JOIN_TYPE_FULL_OUTER:
 		return "join_F";
-	case GNOME_DB_JOIN_TYPE_CROSS:
+	case GDA_QUERY_JOIN_TYPE_CROSS:
 		return "join_C";
 	default:
 		g_assert_not_reached ();
@@ -829,21 +825,21 @@ join_type_to_char (GnomeDbJoinType type)
 static void
 popup_delete_cb (GtkMenuItem *mitem, GnomeDbCanvasJoin *cc)
 {
-	GnomeDbCondition *cond;
+	GdaQueryCondition *cond;
 #ifdef debug
-	GnomeDbQuery *query;
+	GdaQuery *query;
 
-	query = gnome_db_join_get_query (cc->priv->join);
+	query = gda_query_join_get_query (cc->priv->join);
 #endif
 	cond = g_object_get_data (G_OBJECT (mitem), "cond");
 	if (cond)
 		/* remove the condition only */
-		gnome_db_base_nullify (GNOME_DB_BASE (cond));
+		gda_object_destroy (GDA_OBJECT (cond));
 	else 
 		/* remove the whole join */
-		gnome_db_base_nullify (GNOME_DB_BASE (cc->priv->join));
+		gda_object_destroy (GDA_OBJECT (cc->priv->join));
 #ifdef debug
-	gnome_db_base_dump (GNOME_DB_BASE (query), 0);
+	gda_object_dump (GDA_OBJECT (query), 0);
 #endif
 }
 
@@ -857,19 +853,19 @@ entity_item_moved_cb (GnomeCanvasItem *entity, GnomeDbCanvasJoin *cc)
 
 
 static void
-gnome_db_canvas_join_set_join (GnomeDbCanvasJoin *cc, GnomeDbJoin *join)
+gnome_db_canvas_join_set_join (GnomeDbCanvasJoin *cc, GdaQueryJoin *join)
 {
 	g_return_if_fail (cc && IS_GNOME_DB_CANVAS_JOIN (cc));
 	g_return_if_fail (cc->priv);
 	if (join)
-		g_return_if_fail (IS_GNOME_DB_JOIN (join ));
+		g_return_if_fail (GDA_IS_QUERY_JOIN (join ));
 	
 	if (cc->priv->join == join)
 		return;
 	
 	if (cc->priv->join) {
 		g_signal_handlers_disconnect_by_func (G_OBJECT (join),
-						      G_CALLBACK (join_nullified_cb), cc);
+						      G_CALLBACK (join_destroyed_cb), cc);
 		g_signal_handlers_disconnect_by_func (G_OBJECT (join),
 						      G_CALLBACK (join_changed_cb), cc);
 		cc->priv->join = NULL;
@@ -877,7 +873,7 @@ gnome_db_canvas_join_set_join (GnomeDbCanvasJoin *cc, GnomeDbJoin *join)
 
 	if (join) {
 		cc->priv->join = join;
-		gnome_db_base_connect_nullify (join, G_CALLBACK (join_nullified_cb), cc);
+		gda_object_connect_destroy (join, G_CALLBACK (join_destroyed_cb), cc);
 		g_signal_connect (G_OBJECT (join), "condition_changed",
 				  G_CALLBACK (join_changed_cb), cc);
 		g_signal_connect (G_OBJECT (join), "type_changed",
